@@ -8,9 +8,9 @@ import subprocess
 def get_out_text(cmd):
     """Run command with arguments and return its output.
 
-    cmd(list): Command to be executed.
-        The cmd format is ["command", ["arg", "arg1",...]]
-    """
+    :param cmd(list): Command to be executed.
+        The command format is ["command", ["arg", "arg1",...]]
+    :return(str): Command execution results of cmd."""
 
     code = 0
     try:
@@ -20,8 +20,8 @@ def get_out_text(cmd):
         code = e.returncode
     out_text = out_bytes.decode('utf-8')
     if code:
-        out_text = "Error code is " + code + "\n" +\
-                   "Output text is" + out_bytes.decode('utf-8')
+        out_text = "Error code is " + str(code) + "\n" +\
+                   "Output text is \n" + out_bytes.decode('utf-8')
     else:
-        out_text = "Output text is" + out_bytes.decode('utf-8')
+        out_text = "Output text is \n" + out_bytes.decode('utf-8')
     return out_text
