@@ -3,6 +3,8 @@
 
 """Some functions related to file operations."""
 import os
+from user_tools import util_time
+from user_tools import util_check
 import user_tools.util_time as ut
 import user_tools.util_check as uc
 
@@ -58,8 +60,8 @@ def read_file(file_path, mode="r", encoding="UTF-8"):
             file_path not file; file_path not exist; file_path is null."""
 
     msg = ""
-    expr1 = uc.is_not_null(file_path)
-    expr2 = uc.file_or_dir(file_path) == "file"
+    expr1 = util_check.is_not_null(file_path)
+    expr2 = util_check.file_or_dir(file_path) == "file"
     if expr1 and expr2:
         if "b" not in mode:
             with open(file_path, mode, encoding=encoding) as f:
@@ -97,7 +99,7 @@ def get_file_size(file_path, size_unit="MB"):
     else:
         size_unit = SIZE_UNIT["MB"]
     file_size = -1
-    if uc.is_exist(file_path):
+    if util_check.is_exist(file_path):
         tmp_size = os.path.getsize(file_path)
         size = tmp_size / size_unit
         file_size = round(size, 2)
@@ -129,9 +131,9 @@ def get_file_ctime(file_path, format_str='%Y-%m-%d %H:%M:%S'):
         If the creation time is an empty string, the file does not exist."""
 
     ctime = ""
-    if uc.is_exist(file_path):
+    if util_check.is_exist(file_path):
         tmp_time = os.path.getctime(file_path)
-        ctime = ut.format_time(tmp_time, format_str)
+        ctime = util_time.format_time(tmp_time, format_str)
     return ctime
 
 
@@ -160,9 +162,9 @@ def get_file_atime(file_path, format_str='%Y-%m-%d %H:%M:%S'):
         If the access time is an empty string, the file does not exist."""
 
     atime = ""
-    if uc.is_exist(file_path):
+    if util_check.is_exist(file_path):
         tmp_time = os.path.getatime(file_path)
-        atime = ut.format_time(tmp_time, format_str)
+        atime = util_time.format_time(tmp_time, format_str)
     return atime
 
 
@@ -191,7 +193,7 @@ def get_file_mtime(file_path, format_str='%Y-%m-%d %H:%M:%S'):
         If the modification time is an empty string, the file does not exist."""
 
     mtime = ""
-    if uc.is_exist(file_path):
+    if util_check.is_exist(file_path):
         tmp_time = os.path.getmtime(file_path)
-        mtime = ut.format_time(tmp_time, format_str)
+        mtime = util_time.format_time(tmp_time, format_str)
     return mtime
