@@ -4,9 +4,9 @@
 """Some functions related to image operations."""
 import string
 from os.path import basename
-from user_tools import util_hashlib as uh
-from user_tools import util_check as uc
-from user_tools import util_file as uf
+from user_tools import util_hashlib
+from user_tools import util_check
+from user_tools import util_file
 
 
 UPPER_LETTER = string.ascii_uppercase
@@ -27,13 +27,14 @@ def rename_img(img_name):
             not file; not exist; is null; file type not in IMG_SUFFIX.\n"""
 
     real_name = ""
-    expr1 = uc.file_or_dir(img_name) == "file"
-    expr2 = uc.is_not_null(img_name)
+    expr1 = util_check.file_or_dir(img_name) == "file"
+    expr2 = util_check.is_not_null(img_name)
     if expr1 and expr2:
-        suffix = uf.get_file_suffix(img_name)
+        suffix = util_file.get_file_suffix(img_name)
         if suffix in IMG_SUFFIX:
-            md5_name_prefix = uh.get_file_md5(img_name)[:5]
-            time_str = uf.get_file_mtime(img_name, format_str="%Y%m%d%H%M%S")
+            md5_name_prefix = util_hashlib.get_file_md5(img_name)[:5]
+            time_str = util_file.get_file_mtime(img_name, format_str="%Y%m%d%H%M%S")
+            real_name += time_str + "_"
             for i in md5_name_prefix:
                 if i.isdigit():
                     real_name += str(i)
