@@ -3,7 +3,7 @@
 
 """Some functions related to json file operations."""
 import json
-from user_tools import util_check as uc
+from user_tools import util_check
 
 
 def read_json(json_file):
@@ -15,8 +15,8 @@ def read_json(json_file):
             json_file not file; json_file not exist; json_file is null."""
 
     json_dict = {}
-    expr1 = uc.is_not_null(file_path)
-    expr2 = uc.file_or_dir(file_path) == "file"
+    expr1 = util_check.is_not_null(json_file)
+    expr2 = util_check.file_or_dir(json_file) == "file"
     if expr1 and expr2:
         with open(json_file, "r", encoding="UTF-8") as f:
             json_dict = json.load(f)
