@@ -10,10 +10,10 @@ NOW_TIME = time.time()
 def format_time(timestamp=NOW_TIME, format_str='%Y-%m-%d %H:%M:%S'):
     """Format timestamp returns format_str time.
 
-    timestamp(float): The timestamp to be formatted.
-        Defaults to the current timestamp.
-    format_str(str): Time format used to format time.
-        Default is '%Y-%m-%d %H:%M:%S'
+    :param timestamp(float): The timestamp to be formatted.
+        Defaults is the current timestamp.
+    :param format_str(str): Time format used to format time.
+        Default is '%Y-%m-%d %H:%M:%S'.
         Commonly used format codes:
             %Y  Year with century as a decimal number.
             %m  Month as a decimal number [01,12].
@@ -29,7 +29,7 @@ def format_time(timestamp=NOW_TIME, format_str='%Y-%m-%d %H:%M:%S'):
             %c  Locale's appropriate date and time representation.
             %I  Hour (12-hour clock) as a decimal number [01,12].
             %p  Locale's equivalent of either AM or PM.
-    """
+    :return(str): Formatted time string."""
 
     tmp_time = time.localtime(timestamp)
     return time.strftime(format_str, tmp_time)
